@@ -3,7 +3,7 @@ import abc
 import re
 import math
 
-from blaseball_mike import database
+from blaseball_mike import database, tables
 
 
 
@@ -37,36 +37,6 @@ class GlobalEvent(Base):
 
 class Player(Base):
 
-    @staticmethod
-    def _rating_to_stars(val):
-        return 0.5 * (round(val * 10))
-
-    @property
-    def batting_stars(self):
-        return self._rating_to_stars(((1 - self.tragicness) ** 0.01) * ((1 - self.patheticism) ** 0.05) *
-                                     ((self.thwackability * self.divinity) ** 0.35) *
-                                     ((self.moxie * self.musclitude) ** 0.075) * (self.martyrdom ** 0.02))
-
-    @property
-    def pitching_stars(self):
-        return self._rating_to_stars((self.unthwackability ** 0.5) * (self.ruthlessness ** 0.4) *
-                                     (self.overpowerment ** 0.15) * (self.shakespearianism ** 0.1) *
-                                     (self.coldness ** 0.025))
-
-    @property
-    def baserunning_stars(self):
-        return self._rating_to_stars((self.laserlikeness**0.5) *
-                                     ((self.continuation * self.base_thirst * self.indulgence * self.ground_friction) ** 0.1))
-
-    @property
-    def defense_stars(self):
-        return self._rating_to_stars(((self.omniscience * self.tenaciousness) ** 0.2) *
-                                     ((self.watchfulness * self.anticapitalism * self.chasiness) ** 0.1))
-
-    def get_vibe(self, day):
-        return 0.5 * ((self.pressurization + self.cinnamon) * math.cos((math.pi * day) / (5 * self.buoyancy + 3)) -
-                      self.pressurization + self.cinnamon)
-
     @classmethod
     def load(cls, *ids):
         """
@@ -84,6 +54,67 @@ class Player(Base):
         """
         return cls.load(id_).get(id_)
 
+    @property
+    def batting_rating(self):
+        return (((1 - self.tragicness) ** 0.01) * ((1 - self.patheticism) ** 0.05) *
+                ((self.thwackability * self.divinity) ** 0.35) *
+                ((self.moxie * self.musclitude) ** 0.075) * (self.martyrdom ** 0.02))
+
+    @property
+    def pitching_rating(self):
+        return ((self.unthwackability ** 0.5) * (self.ruthlessness ** 0.4) *
+                (self.overpowerment ** 0.15) * (self.shakespearianism ** 0.1) * (self.coldness ** 0.025))
+
+    @property
+    def baserunning_rating(self):
+        return ((self.laserlikeness**0.5) *
+                ((self.continuation * self.base_thirst * self.indulgence * self.ground_friction) ** 0.1))
+
+    @property
+    def defense_rating(self):
+        return (((self.omniscience * self.tenaciousness) ** 0.2) *
+                ((self.watchfulness * self.anticapitalism * self.chasiness) ** 0.1))
+
+    @staticmethod
+    def _rating_to_stars(val):
+        return 0.5 * (round(val * 10))
+
+    @property
+    def batting_stars(self):
+        return self._rating_to_stars(self.batting_rating)
+
+    @property
+    def pitching_stars(self):
+        return self._rating_to_stars(self.pitching_rating)
+
+    @property
+    def baserunning_stars(self):
+        return self._rating_to_stars(self.baserunning_rating)
+
+    @property
+    def defense_stars(self):
+        return self._rating_to_stars(self.defense_rating)
+
+    def get_vibe(self, day):
+        return 0.5 * ((self.pressurization + self.cinnamon) * math.cos((math.pi * day) / (5 * self.buoyancy + 3)) -
+                      self.pressurization + self.cinnamon)
+
+    @property
+    def blood(self):
+        return tables.Blood(self._blood)
+
+    @blood.setter
+    def blood(self, value):
+        self._blood = value
+
+    @property
+    def coffee(self):
+        return tables.Coffee(self._coffee)
+
+    @coffee.setter
+    def coffee(self, value):
+        self._coffee = value
+
 
 class Team(Base):
 
@@ -306,6 +337,14 @@ class Game(Base):
         self._base_runners = None
         self._base_runner_ids = value
 
+    @property
+    def weather(self):
+        return tables.Weather(self._weather)
+
+    @weather.setter
+    def weather(self, value):
+        self._weather = value
+
 
 class DecreeResult(Base):
 
